@@ -2,7 +2,7 @@ import os
 import localstack_client.config
 
 # LocalStack version
-VERSION = '0.11.0'
+VERSION = '0.11.0.1'
 
 # constant to represent the "local" region, i.e., local machine
 REGION_LOCAL = 'local'
@@ -30,6 +30,7 @@ DEFAULT_PORT_EC2_BACKEND = 4555
 DEFAULT_PORT_KMS_BACKEND = 4554
 DEFAULT_PORT_EVENTS_BACKEND = 4553
 DEFAULT_PORT_LOGS_BACKEND = 4552
+DEFAULT_PORT_SSM_BACKEND = 4551
 
 DEFAULT_PORT_WEB_UI = 8080
 
