@@ -8,14 +8,15 @@ import base64
 import traceback
 from six import iteritems
 from flask import Flask, jsonify, request
-from localstack.constants import TEST_AWS_ACCOUNT_ID
+from boto3.dynamodb.types import TypeDeserializer
 from localstack.services import generic_proxy
-from localstack.utils.common import short_uid, to_str
+from localstack.constants import TEST_AWS_ACCOUNT_ID
 from localstack.utils.aws import aws_responses
+from localstack.utils.common import short_uid, to_str, timestamp
 from localstack.utils.aws.aws_stack import (
     get_s3_client, firehose_stream_arn, connect_elasticsearch, extract_region_from_auth_header)
-from boto3.dynamodb.types import TypeDeserializer
 from localstack.utils.kinesis import kinesis_connector
+from localstack.utils.analytics import event_publisher
 
 APP_NAME = 'firehose_api'
 app = Flask(APP_NAME)
@@ -93,8 +94,7 @@ def put_records(stream_name, records):
                 elif 'data' in record:
                     data = base64.b64decode(record['data'])
 
-                obj_name = str(uuid.uuid4())
-                obj_path = '%s%s%s' % (prefix, '' if prefix.endswith('/') else '/', obj_name)
+                obj_path = get_s3_object_path(stream_name, prefix)
                 try:
                     s3.Object(bucket, obj_path).put(Body=data)
                 except Exception as e:
@@ -102,6 +102,17 @@ def put_records(stream_name, records):
                     raise e
 
 
+def get_s3_object_path(stream_name, prefix):
+    # See https://aws.amazon.com/kinesis/data-firehose/faqs/#Data_delivery
+    # Path prefix pattern: myApp/YYYY/MM/DD/HH/
+    # Object name pattern: DeliveryStreamName-DeliveryStreamVersion-YYYY-MM-DD-HH-MM-SS-RandomString
+    prefix = '%s%s' % (prefix, '' if prefix.endswith('/') else '/')
+    pattern = '{pre}%Y/%m/%d/%H/{name}-%Y-%m-%d-%H-%M-%S-{rand}'
+    path = pattern.format(pre=prefix, name=stream_name, rand=str(uuid.uuid4()))
+    path = timestamp(format=path)
+    return path
+
+
 def get_destination(stream_name, destination_id):
     stream = get_stream(stream_name)
     destinations = stream['Destinations']
@@ -151,12 +162,15 @@ def create_stream(stream_name, delivery_stream_type='DirectPut', delivery_stream
     }
     DELIVERY_STREAMS[stream_name] = stream
     if elasticsearch_destination:
-        update_destination(stream_name=stream_name,
-                           destination_id=short_uid(),
+        update_destination(stream_name=stream_name, destination_id=short_uid(),
                            elasticsearch_update=elasticsearch_destination)
     if s3_destination:
         update_destination(stream_name=stream_name, destination_id=short_uid(), s3_update=s3_destination)
 
+    # record event
+    event_publisher.fire_event(event_publisher.EVENT_FIREHOSE_CREATE_STREAM,
+        payload={'n': event_publisher.get_hash(stream_name)})
+
     if delivery_stream_type == 'KinesisStreamAsSource':
         kinesis_stream_name = delivery_stream_type_configuration.get('KinesisStreamARN').split('/')[1]
         kinesis_connector.listen_to_kinesis(
@@ -170,6 +184,11 @@ def delete_stream(stream_name):
     stream = DELIVERY_STREAMS.pop(stream_name, {})
     if not stream:
         return error_not_found(stream_name)
+
+    # record event
+    event_publisher.fire_event(event_publisher.EVENT_FIREHOSE_DELETE_STREAM,
+        payload={'n': event_publisher.get_hash(stream_name)})
+
     return {}
 
 
@@ -209,12 +228,16 @@ def post_request():
     elif action == '%s.CreateDeliveryStream' % ACTION_HEADER_PREFIX:
         stream_name = data['DeliveryStreamName']
         region_name = extract_region_from_auth_header(request.headers)
+        _s3_destination = data.get('S3DestinationConfiguration') or data.get('ExtendedS3DestinationConfiguration')
         response = create_stream(
-            stream_name, delivery_stream_type=data.get('DeliveryStreamType'),
+            stream_name,
+            delivery_stream_type=data.get('DeliveryStreamType'),
             delivery_stream_type_configuration=data.get('KinesisStreamSourceConfiguration'),
-            s3_destination=data.get('S3DestinationConfiguration'),
+            s3_destination=_s3_destination,
             elasticsearch_destination=data.get('ElasticsearchDestinationConfiguration'),
-            tags=data.get('Tags'), region_name=region_name)
+            tags=data.get('Tags'),
+            region_name=region_name
+        )
     elif action == '%s.DeleteDeliveryStream' % ACTION_HEADER_PREFIX:
         stream_name = data['DeliveryStreamName']
         response = delete_stream(stream_name)
@@ -237,9 +260,12 @@ def post_request():
         stream_name = data['DeliveryStreamName']
         records = data['Records']
         put_records(stream_name, records)
+        request_responses = []
+        for i in records:
+            request_responses.append({'RecordId': str(uuid.uuid4())})
         response = {
             'FailedPutCount': 0,
-            'RequestResponses': []
+            'RequestResponses': request_responses
         }
     elif action == '%s.UpdateDestination' % ACTION_HEADER_PREFIX:
         stream_name = data['DeliveryStreamName']
@@ -250,7 +276,7 @@ def post_request():
                            s3_update=s3_update, version_id=version_id)
         es_update = data['ESDestinationUpdate'] if 'ESDestinationUpdate' in data else None
         update_destination(stream_name=stream_name, destination_id=destination_id,
-                           es_update=es_update, version_id=version_id)
+                           elasticsearch_update=es_update, version_id=version_id)
         response = {}
     elif action == '%s.ListTagsForDeliveryStream' % ACTION_HEADER_PREFIX:
         response = get_delivery_stream_tags(data['DeliveryStreamName'], data.get('ExclusiveStartTagKey'),
